pub enum NinjaCommand {
Stage {
strict: bool,
json: bool,
},
Build {
glibc: Option<String>,
release: bool,
target: Option<String>,
},
}Variants
Stage
fmt, lint & test then stage everything in git if all is good
To provide any specfic environment variables for the executed cargo commands create a workspace metadata section in Cargo.toml (if this is a single crate, you can add the section to the crate Cargo.toml without a problem, if it’s a workspace add it to the workspace Cargo.toml). For example:
[workspace.metadata.ninja-xtask]
env = {
"LD_LIBRARY_PATH" = false, # unset variable, do not inherit
"RUSTFLAGS" = "flag" # set variable, overwriting inherited value
}Build
build (optionally with zigbuild for a given glibc version)